%global whl_version     %%(echo %{__default_python3_version} | tr -d '.')
%global proton_datadir  %{_datadir}/proton
%global __cmake_in_source_build 1

%global __provides_exclude_from ^%{proton_datadir}/examples/.*$
%global __requires_exclude_from ^%{proton_datadir}/examples/.*$
%define whl_arch "%{_arch}"

%undefine __brp_mangle_shebangs

Summary:        A high performance, lightweight messaging library
Name:           qpid-proton
Version:        0.39.0
Release:        1%{?dist}
License:        ASL 2.0
URL:            http://qpid.apache.org/proton/
Source0:        %{name}-%{version}.tar.gz
Source1:        licenses.xml

BuildRequires:  gcc gcc-c++ cmake swig pkgconfig doxygen libuuid-devel python3-pip
BuildRequires:  openssl-devel python3-devel python3-rpm-macros python3-sphinx python3-wheel python3-cffi
BuildRequires:  glibc-headers cyrus-sasl-devel jsoncpp-devel python3-setuptools libuv-devel nspr-devel

%description
Proton is a high performance, lightweight messaging library. It can be used in the widest range of
messaging applications including brokers, client libraries, routers, bridges, proxies, and more.
Proton is based on the AMQP 1.0 messaging standard. Using Proton it is trivial to integrate with the
AMQP 1.0 ecosystem from any platform, environment, or language.

%package c
Summary:   C libraries for Qpid Proton
Requires:  cyrus-sasl-lib

%description c
A high performance, lightweight messaging library.

%package   cpp
Summary:   C++ libraries for Qpid Proton
Requires:  qpid-proton-c = %{version}-%{release} jsoncpp

%description cpp
A high performance, lightweight messaging library.

%package c-devel
Summary:   Development libraries for writing messaging apps with Qpid Proton
Requires:  qpid-proton-c = %{version}-%{release}

%description c-devel
A high performance, lightweight messaging library.

%package cpp-devel
Summary:   Development libraries for writing messaging apps with Qpid Proton
Requires:  qpid-proton-cpp = %{version}-%{release}
Requires:  qpid-proton-c-devel = %{version}-%{release}

%description cpp-devel
A high performance, lightweight messaging library.

%package c-docs
Summary:   Documentation for the C development libraries for Qpid Proton
BuildArch: noarch

%description c-docs
A high performance, lightweight messaging library.

%package   cpp-docs
Summary:   Documentation for the C++ development libraries for Qpid Proton
BuildArch: noarch

%description cpp-docs
A high performance, lightweight messaging library.

%package -n python3-qpid-proton
Summary:  Python language bindings for the Qpid Proton messaging framework
Requires: qpid-proton-c = %{version}-%{release}
Requires: python3
Provides: python%{python3_version}dist(python-qpid-proton)

%description -n python3-qpid-proton
A high performance, lightweight messaging library.

%package -n python-qpid-proton-docs
Summary:   Documentation for the Python language bindings for Qpid Proton
BuildArch: noarch

%description -n python-qpid-proton-docs
A high performance, lightweight messaging library.

%package tests
Summary:   Qpid Proton Tests
BuildArch: noarch

%description tests
A high performance, lightweight messaging library.

%prep
%autosetup -n %{name}-%{version} -p1

%build
mkdir -p BLD
cd BLD
%cmake \
    -DCMAKE_SKIP_RPATH:BOOL=OFF \
   "-DCMAKE_C_FLAGS=$CFLAGS -Wno-deprecated-declarations" \
    -DBUILD_TESTING=OFF \
    -DENABLE_FUZZ_TESTING=NO \
    ..
make all docs %{?_smp_mflags}


%install
rm -rf %{buildroot}

cd BLD
%cmake_install

pushd python/
rm -rf build
PKG_CONFIG_PATH=%{buildroot}%{_libdir}/pkgconfig %py3_build_wheel
%py3_install_wheel python_qpid_proton-%{version}-cp%{whl_version}-cp%{whl_version}-linux_%{whl_arch}.whl
popd

install -dm 755 %{buildroot}%{proton_datadir}
install -pm 644 %{SOURCE1} %{buildroot}%{proton_datadir}

rm -rf %{buildroot}%{_exec_prefix}/bindings
rm -rf %{buildroot}%{_libdir}/java
rm -rf %{buildroot}%{_libdir}/libproton-jni.so
rm -rf %{buildroot}%{_datarootdir}/java
rm -rf %{buildroot}%{_libdir}/proton.cmake
rm -f  %{buildroot}%{proton_datadir}/CMakeLists.txt

%check

%files c
%dir %{proton_datadir}
%license %{proton_datadir}/LICENSE.txt
%license %{proton_datadir}/licenses.xml
%doc %{proton_datadir}/README*
%{_libdir}/libqpid-proton.so.*
%{_libdir}/libqpid-proton-core.so.*
%{_libdir}/libqpid-proton-proactor.so.*

%files cpp
%dir %{proton_datadir}
%doc %{proton_datadir}/README*
%{_libdir}/libqpid-proton-cpp.so.*

%files c-devel
%{_includedir}/proton
%{_libdir}/libqpid-proton.so
%{_libdir}/libqpid-proton-core.so
%{_libdir}/libqpid-proton-proactor.so
%{_libdir}/pkgconfig/libqpid-proton.pc
%{_libdir}/pkgconfig/libqpid-proton-core.pc
%{_libdir}/pkgconfig/libqpid-proton-proactor.pc
%{_libdir}/cmake/Proton
%exclude %{_includedir}/proton/*.hpp
%exclude %{_includedir}/proton/**/*.hpp

%files cpp-devel
%{_includedir}/proton/*.hpp
%{_includedir}/proton/**/*.hpp
%{_libdir}/pkgconfig/libqpid-proton-cpp.pc
%{_libdir}/libqpid-proton-cpp.so
%{_libdir}/cmake/ProtonCpp

%files c-docs
%license %{proton_datadir}/LICENSE.txt
%doc %{proton_datadir}/docs/api-c
%doc %{proton_datadir}/examples/README.md
%doc %{proton_datadir}/examples/c/

%files cpp-docs
%license %{proton_datadir}/LICENSE.txt
%{proton_datadir}/docs/api-cpp
%doc %{proton_datadir}/examples/cpp/

%files -n python3-qpid-proton
%{python3_sitearch}/__pycache__/*
%{python3_sitearch}/*.so
%{python3_sitearch}/*.py*
%{python3_sitearch}/proton
%{python3_sitearch}/python_qpid_proton-%{version}.dist-info/*

%files -n python-qpid-proton-docs
%license %{proton_datadir}/LICENSE.txt
%doc %{proton_datadir}/docs/api-py
%doc %{proton_datadir}/examples/python

%files tests
%doc %{proton_datadir}/tests

%changelog
* Sat Oct 07 2023 cunshunxia <cunshunxia@tencent.com> - 0.39.0-1
- Upgrade to version 0.39.0

* Tue Sep 19 2023 OpenCloudOS Release Engineering <releng@opencloudos.tech> - 0.38.0-6
- Rebuilt for python 3.11

* Thu Sep 14 2023 Xiaojie Chen <jackxjchen@tencent.com> - 0.38.0-5
- Add Provides python%{python3_version}dist(python-qpid-proton)

* Fri Sep 08 2023 OpenCloudOS Release Engineering <releng@opencloudos.tech> - 0.38.0-4
- Rebuilt for OpenCloudOS Stream 23.09

* Fri Apr 28 2023 OpenCloudOS Release Engineering <releng@opencloudos.tech> - 0.38.0-3
- Rebuilt for OpenCloudOS Stream 23.05

* Thu Apr 13 2023 Shuo Wang <abushwang@tencent.com> - 0.38.0-2
- add provides for python

* Wed Apr 12 2023 Shuo Wang <abushwang@tencent.com> - 0.38.0-1
- initial build
